<?xml version="1.0" encoding="UTF-8" ?>
<!-- $Id: cedram-to-dmlcz-references.xsl 319 2008-03-24 14:50:35Z michalr $ -->
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
               xmlns:str="http://exslt.org/strings">
    
    <!-- Output setup. -->
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!-- Math expressions conversion. -->
    <xsl:template match="texmath">
        <xsl:if test="@type='inline'">$<xsl:value-of select="."/>$</xsl:if>
        <xsl:if test="@type='display'">\[<xsl:value-of select="."/>\]</xsl:if>
    </xsl:template>
    
    <!-- xml:lang attribute conversion. -->
    <xsl:template match="@xml:lang">
        <xsl:choose>
            <xsl:when test=".='cs'">
                <xsl:attribute name="lang">cze</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='en'">
                <xsl:attribute name="lang">eng</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='de'">
                <xsl:attribute name="lang">ger</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='fr'">
                <xsl:attribute name="lang">fre</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='ru'">
                <xsl:attribute name="lang">rus</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='sk'">
                <xsl:attribute name="lang">slo</xsl:attribute>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <!-- References extraction. -->
    <xsl:template match="/">
        <references>
            <xsl:apply-templates select="/article-metadata/article/biblio/bib_entry">
                <xsl:sort data-type="number" select="./reference/text()"/>
            </xsl:apply-templates>
        </references>
    </xsl:template>
    
    <!-- Bibliography entry extraction. -->
    <xsl:template match="biblio/bib_entry">
        <xsl:variable name="ref" select="./reference"/>
        <reference>
            <xsl:if test="./reference">
                <xsl:attribute name="id">
                    <xsl:value-of select="$ref"/>
                </xsl:attribute>
                <prefix>
                    <xsl:text>[</xsl:text>
                    <xsl:value-of select="./reference"/>
                    <xsl:text>]</xsl:text>
                </prefix>
            </xsl:if>
            <xsl:if test="./TeXtitle">
                <title>
                    <xsl:apply-templates select="./TeXtitle"/>
                </title>
            </xsl:if>
            <xsl:if test="./TeXbooktitle">
                <booktitle>
                    <xsl:apply-templates select="./TeXbooktitle"/>
                </booktitle>
            </xsl:if>
            <xsl:if test="./auteur">
                <authors>
                    <xsl:apply-templates select="./auteur"/>
                </authors>
            </xsl:if>
            <xsl:if test="./editeur">
                <editors>
                    <xsl:apply-templates select="./editeur"/>
                </editors>
            </xsl:if>
            <xsl:if test="./address">
                <address>
                    <xsl:apply-templates select="./address"/>
                </address>
            </xsl:if>
            <xsl:if test="./chapter">
                <chapter>
                    <xsl:apply-templates select="./chapter"/>
                </chapter>
            </xsl:if>
            <xsl:if test="./edition">
                <edition>
                    <xsl:apply-templates select="./edition"/>
                </edition>
            </xsl:if>
            <xsl:if test="./howpublished">
                <howpublished>
                    <xsl:apply-templates select="./howpublished"/>
                </howpublished>
            </xsl:if>
            <xsl:if test="./institution">
                <institution>
                    <xsl:apply-templates select="./institution"/>
                </institution>
            </xsl:if>
            <xsl:if test="./journal">
                <journal>
                    <xsl:apply-templates select="./journal"/>
                </journal>
            </xsl:if>
            <xsl:if test="./month">
                <month>
                    <xsl:apply-templates select="./month"/>
                </month>
            </xsl:if>
            <xsl:if test="./note">
                <note>
                    <xsl:apply-templates select="./note"/>
                </note>
            </xsl:if>
            <xsl:if test="./number">
                <number>
                    <xsl:apply-templates select="./number"/>
                </number>
            </xsl:if>
            <xsl:if test="./organization">
                <organization>
                    <xsl:apply-templates select="./organization"/>
                </organization>
            </xsl:if>
            <xsl:if test="./publisher">
                <publisher>
                    <xsl:apply-templates select="./publisher"/>
                </publisher>
            </xsl:if>
            <xsl:if test="./school">
                <school>
                    <xsl:apply-templates select="./school"/>
                </school>
            </xsl:if>
            <xsl:if test="./series">
                <series>
                    <xsl:apply-templates select="./series"/>
                </series>
            </xsl:if>
            <xsl:if test="./typo">
                <type>
                    <xsl:apply-templates select="./type"/>
                </type>
            </xsl:if>
            <xsl:if test="./volume">
                <volume>
                    <xsl:apply-templates select="./volume"/>
                </volume>
            </xsl:if>
            <xsl:if test="./year">
                <year>
                    <xsl:apply-templates select="./year"/>
                </year>
            </xsl:if>
            <xsl:if test="./pagedeb or ./pagefin">
                <pages>
                    <xsl:if test="./pagedeb">
                        <first-page>
                            <xsl:apply-templates select="./pagedeb"/>
                        </first-page>
                    </xsl:if>
                    <xsl:if test="./pagefin">
                        <last-page>
                            <xsl:apply-templates select="./pagefin"/>
                        </last-page>
                    </xsl:if>
                </pages>
            </xsl:if>
            <xsl:if test="/article-metadata/suffixes/suffix">
                <suffix>
                    <xsl:apply-templates select="/article-metadata/suffixes/suffix[position()=$ref]"/>
                </suffix>
            </xsl:if>
        </reference>
    </xsl:template>
    
    <!-- Bibliography authors extraction. -->
    <xsl:template match="bib_entry/auteur">
        <author>
            <xsl:apply-templates select="nom"/>
            <xsl:text>, </xsl:text>
            <xsl:apply-templates select="prenom"/>
        </author>
    </xsl:template>
    
    <!-- Bibliography editors extraction. -->
    <xsl:template match="bib_entry/editeur">
        <editor>
            <xsl:apply-templates select="nom"/>
            <xsl:text>, </xsl:text>
            <xsl:apply-templates select="prenom"/>
        </editor>
    </xsl:template>
    
</xsl:transform>
